EXPORTS
	??0TBTBasebandLinkState@@QAE@XZ @ 1 NONAME ; TBTBasebandLinkState::TBTBasebandLinkState(void)
	??0TBTFeatures@@QAE@XZ @ 2 NONAME ; TBTFeatures::TBTFeatures(void)
	??0TBTFeatures@@QAE@_K@Z @ 3 NONAME ; TBTFeatures::TBTFeatures(unsigned long long)
	??ATBTFeatures@@QBEHH@Z @ 4 NONAME ; int TBTFeatures::operator[](int) const
	?Authenticated@TBTBasebandLinkState@@QBEHXZ @ 5 NONAME ; int TBTBasebandLinkState::Authenticated(void) const
	?Encrypted@TBTBasebandLinkState@@QBEHXZ @ 6 NONAME ; int TBTBasebandLinkState::Encrypted(void) const
	?IsEncryptionPauseResumeSupported@TBTFeatures@@QBEHXZ @ 7 NONAME ; int TBTFeatures::IsEncryptionPauseResumeSupported(void) const
	?IsEncryptionSupported@TBTFeatures@@QBEHXZ @ 8 NONAME ; int TBTFeatures::IsEncryptionSupported(void) const
	?IsExtendedInquiryResponseSupported@TBTFeatures@@QBEHXZ @ 9 NONAME ; int TBTFeatures::IsExtendedInquiryResponseSupported(void) const
	?IsExtendedSCOLinkSupported@TBTFeatures@@QBEHXZ @ 10 NONAME ; int TBTFeatures::IsExtendedSCOLinkSupported(void) const
	?IsModeAllowed@TLinkPolicy@@QBEHW4TBTLinkMode@@@Z @ 11 NONAME ; int TLinkPolicy::IsModeAllowed(enum TBTLinkMode) const
	?IsModeSupported@TBTFeatures@@QBEHW4TBTLinkMode@@@Z @ 12 NONAME ; int TBTFeatures::IsModeSupported(enum TBTLinkMode) const
	?IsRoleSwitchSupported@TBTFeatures@@QBEHXZ @ 13 NONAME ; int TBTFeatures::IsRoleSwitchSupported(void) const
	?IsRssiWithInquiryResultsSupported@TBTFeatures@@QBEHXZ @ 14 NONAME ; int TBTFeatures::IsRssiWithInquiryResultsSupported(void) const
	?IsSCOLinkSupported@TBTFeatures@@QBEHXZ @ 15 NONAME ; int TBTFeatures::IsSCOLinkSupported(void) const
	?IsSecureSimplePairingSupported@TBTFeatures@@QBEHXZ @ 16 NONAME ; int TBTFeatures::IsSecureSimplePairingSupported(void) const
	?IsSwitchAllowed@TLinkPolicy@@QBEHXZ @ 17 NONAME ; int TLinkPolicy::IsSwitchAllowed(void) const
	?LinkMode@TBTBasebandLinkState@@QBE?AW4TBTLinkMode@@XZ @ 18 NONAME ; enum TBTLinkMode TBTBasebandLinkState::LinkMode(void) const
	?LinkModes@TBTFeatures@@QBEKXZ @ 19 NONAME ; unsigned long TBTFeatures::LinkModes(void) const
	?LinkPolicy@TLinkPolicy@@QBEEXZ @ 20 NONAME ; unsigned char TLinkPolicy::LinkPolicy(void) const
	?LinkRole@TBTBasebandLinkState@@QBE?AW4TBTBasebandRole@@XZ @ 21 NONAME ; enum TBTBasebandRole TBTBasebandLinkState::LinkRole(void) const
	?LinkState@TBTBasebandLinkState@@QBE?AW4TLinkState@1@XZ @ 22 NONAME ; enum TBTBasebandLinkState::TLinkState TBTBasebandLinkState::LinkState(void) const
	?LowPowerModePolicy@TLinkPolicy@@QBEEXZ @ 23 NONAME ; unsigned char TLinkPolicy::LowPowerModePolicy(void) const
	?MaxSlots@TBTBasebandLinkState@@QBEEXZ @ 24 NONAME ; unsigned char TBTBasebandLinkState::MaxSlots(void) const
	?PacketTypes@TBTBasebandLinkState@@QBEGXZ @ 25 NONAME ; unsigned short TBTBasebandLinkState::PacketTypes(void) const
	?SCOPackets@TBTFeatures@@QBEGXZ @ 26 NONAME ; unsigned short TBTFeatures::SCOPackets(void) const
	?SetAuthenticated@TBTBasebandLinkState@@QAEXH@Z @ 27 NONAME ; void TBTBasebandLinkState::SetAuthenticated(int)
	?SetEncrypted@TBTBasebandLinkState@@QAEXH@Z @ 28 NONAME ; void TBTBasebandLinkState::SetEncrypted(int)
	?SetLinkMode@TBTBasebandLinkState@@QAEXW4TBTLinkMode@@@Z @ 29 NONAME ; void TBTBasebandLinkState::SetLinkMode(enum TBTLinkMode)
	?SetLinkRole@TBTBasebandLinkState@@QAEXW4TBTBasebandRole@@@Z @ 30 NONAME ; void TBTBasebandLinkState::SetLinkRole(enum TBTBasebandRole)
	?SetLinkState@TBTBasebandLinkState@@QAEXW4TLinkState@1@@Z @ 31 NONAME ; void TBTBasebandLinkState::SetLinkState(enum TBTBasebandLinkState::TLinkState)
	?SetMaxSlots@TBTBasebandLinkState@@QAEXE@Z @ 32 NONAME ; void TBTBasebandLinkState::SetMaxSlots(unsigned char)
	?SetModeAllowed@TLinkPolicy@@QAEXW4TBTLinkMode@@H@Z @ 33 NONAME ; void TLinkPolicy::SetModeAllowed(enum TBTLinkMode, int)
	?SetModesAllowed@TLinkPolicy@@QAEXE@Z @ 34 NONAME ; void TLinkPolicy::SetModesAllowed(unsigned char)
	?SetPacketTypes@TBTBasebandLinkState@@QAEXG@Z @ 35 NONAME ; void TBTBasebandLinkState::SetPacketTypes(unsigned short)
	?SetSwitchAllowed@TLinkPolicy@@QAEXH@Z @ 36 NONAME ; void TLinkPolicy::SetSwitchAllowed(int)
	?SyncPackets@TBTFeatures@@QBEKXZ @ 37 NONAME ; unsigned long TBTFeatures::SyncPackets(void) const

